% Auto-generated chapter 39 for tirmidhi
% Hadiths in this chapter: 34

\hadithdefcmd{tirmidhi}{2573}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، عَنِ الْعَلاَءِ بْنِ خَالِدٍ الْكَاهِلِيِّ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُؤْتَى بِجَهَنَّمَ يَوْمَئِذٍ لَهَا سَبْعُونَ أَلْفَ زِمَامٍ مَعَ كُلِّ زِمَامٍ سَبْعُونَ أَلْفَ مَلَكٍ يَجُرُّونَهَا ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ وَالثَّوْرِيُّ لاَ يَرْفَعُهُ ‏.‏ حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو أَبُو عَامِرٍ الْعَقَدِيُّ، عَنْ سُفْيَانَ، عَنِ الْعَلاَءِ بْنِ خَالِدٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{2573}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Mas'ud narrated that the Messenger of Allah (s.a.w) said:"Hell will be brought forth on that Day (of Resurrection) having seventy thousand bridles, and with every handle will be seventy thousand angels dragging it'". Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2574}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَخْرُجُ عُنُقٌ مِنَ النَّارِ يَوْمَ الْقِيَامَةِ لَهُ عَيْنَانِ تُبْصِرَانِ وَأُذُنَانِ تَسْمَعَانِ وَلِسَانٌ يَنْطِقُ يَقُولُ إِنِّي وُكِّلْتُ بِثَلاَثَةٍ بِكُلِّ جَبَّارٍ عَنِيدٍ وَبِكُلِّ مَنْ دَعَا مَعَ اللَّهِ إِلَهًا آخَرَ وَبِالْمُصَوِّرِينَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ بَعْضُهُمْ عَنِ الأَعْمَشِ عَنْ عَطِيَّةَ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا وَرَوَى أَشْعَثُ بْنُ سَوَّارٍ عَنْ عَطِيَّةَ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2574}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Some of the Fire (in the shape of a long neck) will come out of the Fire on the Day of judgment. It will have two eyes which can see, two ears which can hear, and a tongue which can speak. It will say: 'I have been left in charge of three: Every obstinate oppressor, everyone who called upon a deity besides Allah, and the image makers." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2575}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ فُضَيْلِ بْنِ عِيَاضٍ، عَنْ هِشَامٍ، عَنِ الْحَسَنِ، قَالَ قَالَ عُتْبَةُ بْنُ غَزْوَانَ عَلَى مِنْبَرِنَا هَذَا مِنْبَرِ الْبَصْرَةِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الصَّخْرَةَ الْعَظِيمَةَ لَتُلْقَى مِنْ شَفِيرِ جَهَنَّمَ فَتَهْوِي فِيهَا سَبْعِينَ عَامًا وَمَا تُفْضِي إِلَى قَرَارِهَا ‏"‏ ‏.‏ قَالَ وَكَانَ عُمَرُ يَقُولُ أَكْثِرُوا ذِكْرَ النَّارِ فَإِنَّ حَرَّهَا شَدِيدٌ وَإِنَّ قَعْرَهَا بَعِيدٌ وَإِنَّ مَقَامِعَهَا حَدِيدٌ ‏.‏ قَالَ أَبُو عِيسَى لاَ نَعْرِفُ لِلْحَسَنِ سَمَاعًا مِنْ عُتْبَةَ بْنِ غَزْوَانَ وَإِنَّمَا قَدِمَ عُتْبَةُ بْنُ غَزْوَانَ الْبَصْرَةَ فِي زَمَنِ عُمَرَ وَوُلِدَ الْحَسَنُ لِسَنَتَيْنِ بَقِيَتَا مِنْ خِلاَفَةِ عُمَرَ ‏.‏\hadithno{2575}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Hasan said:"While he was on the pulpit – the pulpit of Al-Basrah – `Utbah bin Ghazwain narrated that the Messenger of Allah (s.a.w) said: “Indeed a giant rock can be thrown from the brink of Hell and it will continue to fall into it for seventy years without reaching the bottom of it.”.He said: “`Umar used to say:'Increase in your remembrance of the Fire, for its heat is extreme, its bottom is distant, and its whips are of Iron.'” (Sahih)}}
\hadithdefcmd{tirmidhi}{2576}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، عَنِ ابْنِ لَهِيعَةَ، عَنْ دَرَّاجٍ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الصَّعُودُ جَبَلٌ مِنْ نَارٍ يُتَصَعَّدُ فِيهِ الْكَافِرُ سَبْعِينَ خَرِيفًا وَيَهْوِي فِيهِ كَذَلِكَ أَبَدًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ ابْنِ لَهِيعَةَ ‏.‏\hadithno{2576}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Sa'eed narrated that the Prophet SAW said:"As-Saud is a mountain in the Fire, a disbeliever will be raised upon it for seventy autumns and then similarly he will fall down it, forever." (Daif)}}
\hadithdefcmd{tirmidhi}{2577}{حَدَّثَنَا عَبَّاسٌ الدُّورِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَخْبَرَنَا شَيْبَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ غِلَظَ جِلْدِ الْكَافِرِ اثْنَانِ وَأَرْبَعُونَ ذِرَاعًا وَإِنَّ ضِرْسَهُ مِثْلُ أُحُدٍ وَإِنَّ مَجْلِسَهُ مِنْ جَهَنَّمَ كَمَا بَيْنَ مَكَّةَ وَالْمَدِينَةِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ الأَعْمَشِ ‏.‏\hadithno{2577}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Prophet (s.a.w) said:"Indeed a disbeliever's skin will be forty-two forearm lengths thick, his molar teeth will be like Uhud (mountain), and his sitting place in Hell will be like what is between Makkah and Al-Madinah}}
\hadithdefcmd{tirmidhi}{2578}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ عَمَّارٍ، حَدَّثَنِي جَدِّي، مُحَمَّدُ بْنُ عَمَّارٍ وَصَالِحٌ مَوْلَى التَّوْأَمَةِ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ضِرْسُ الْكَافِرِ يَوْمَ الْقِيَامَةِ مِثْلُ أُحُدٍ وَفَخِذُهُ مِثْلُ الْبَيْضَاءِ وَمَقْعَدُهُ مِنَ النَّارِ مَسِيرَةَ ثَلاَثٍ مِثْلُ الرَّبَذَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ ‏"‏ وَمِثْلُ الرَّبَذَةِ ‏"‏ كَمَا بَيْنَ الْمَدِينَةِ وَالرَّبَذَةِ ‏.‏ وَالْبَيْضَاءُ جَبَلٌ مِثْلُ أُحُدٍ ‏.‏\hadithno{2578}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"The molar teeth of the disbeliever on the Day of Judgment will be like Uhud (mountain), his thigh will be like Al-Baida, and his seat in the Fire will be like the distance of three the likes of Ar-Rabadhah." His SAW statement: "The likes of Ar-Rabadhah" means: like what is between Al-Madinah and ArRabadhah. And Al-Baidã' is a mountain like Uhud}}
\hadithdefcmd{tirmidhi}{2579}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُصْعَبُ بْنُ الْمِقْدَامِ، عَنْ فُضَيْلِ بْنِ غَزْوَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، رَفَعَهُ قَالَ ‏ "‏ ضِرْسُ الْكَافِرِ مِثْلُ أُحُدٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَأَبُو حَازِمٍ هُوَ الأَشْجَعِيُّ اسْمُهُ سَلْمَانُ مَوْلَى عَزَّةَ الأَشْجَعِيَّةِ ‏.‏\hadithno{2579}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated a Marfu' narration:"The molar teeth of the disbeliever will be like Uhud (mountain)}}
\hadithdefcmd{tirmidhi}{2580}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الْفَضْلِ بْنِ يَزِيدَ، عَنْ أَبِي الْمُخَارِقِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْكَافِرَ لَيُسْحَبُ لِسَانُهُ الْفَرْسَخَ وَالْفَرْسَخَيْنِ يَتَوَطَّؤُهُ النَّاسُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْفَضْلُ بْنُ يَزِيدَ هُوَ كُوفِيٌّ قَدْ رَوَى عَنْهُ غَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ وَأَبُو الْمُخَارِقِ لَيْسَ بِمَعْرُوفٍ ‏.‏\hadithno{2580}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah (s.a.w) said:'Indeed the disbeliever's tongue will be stretched a Farsakh or two Farsakh, such that the people will walk upon it}}
\hadithdefcmd{tirmidhi}{2581}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ دَرَّاجٍ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي قَوْلِهِ‏:‏ ‏(‏كَالْمُهْلِ ‏)‏ قَالَ ‏ "‏ كَعَكَرِ الزَّيْتِ فَإِذَا قَرَّبَهُ إِلَى وَجْهِهِ سَقَطَتْ فَرْوَةُ وَجْهِهِ فِيهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ رِشْدِينَ بْنِ سَعْدٍ ‏.‏ وَرِشْدِينُ قَدْ تُكُلِّمَ فِيهِ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{2581}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Abu Sa'eed narrated regarding His (Allah's) statement:Kal Muhl, the Prophet (s.a.w)said: 'Like boiling oil, such that when it is brought close to his face, the skin of his face will fall off into it}}
\hadithdefcmd{tirmidhi}{2582}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا سَعِيدُ بْنُ يَزِيدَ، عَنْ أَبِي السَّمْحِ، عَنِ ابْنِ حُجَيْرَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْحَمِيمَ لَيُصَبُّ عَلَى رُءُوسِهِمْ فَيَنْفُذُ الْحَمِيمُ حَتَّى يَخْلُصَ إِلَى جَوْفِهِ فَيَسْلِتَ مَا فِي جَوْفِهِ حَتَّى يَمْرُقَ مِنْ قَدَمَيْهِ وَهُوَ الصَّهْرُ ثُمَّ يُعَادُ كَمَا كَانَ ‏"‏ ‏.‏ وَسَعِيدُ بْنُ يَزِيدَ يُكْنَى أَبَا شُجَاعٍ وَهُوَ مِصْرِيٌّ وَقَدْ رَوَى عَنْهُ اللَّيْثُ بْنُ سَعْدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَابْنُ حُجَيْرَةَ هُوَ عَبْدُ الرَّحْمَنِ بْنُ حُجَيْرَةَ الْمِصْرِيُّ ‏.‏\hadithno{2582}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Prophet (s.a.w) said:Indeed Hamim will be poured over their heads. The Hamim will penetrate until it finds its way to his insides. Then whatever is inside him will fall out until it pours over his feet while it melts away. Then he will be reformed to how he was}}
\hadithdefcmd{tirmidhi}{2583}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا صَفْوَانُ بْنُ عَمْرٍو، عَنْ عُبَيْدِ اللَّهِ بْنِ بُسْرٍ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي قَوْلِهِ‏:‏ ‏(‏يُسْقَى مِنْ مَاءٍ صَدِيدٍ * يَتَجَرَّعُهُ ‏)‏ قَالَ ‏"‏ يُقَرَّبُ إِلَى فِيهِ فَيَكْرَهُهُ فَإِذَا أُدْنِيَ مِنْهُ شَوَى وَجْهَهُ وَوَقَعَتْ فَرْوَةُ رَأْسِهِ فَإِذَا شَرِبَهُ قَطَّعَ أَمْعَاءَهُ حَتَّى يَخْرُجَ مِنْ دُبُرِهِ يَقُولُ اللَّهُ‏:‏ ‏(‏وَسُقُوا مَاءً حَمِيمًا فَقَطَّعَ أَمْعَاءَهُمْ ‏)‏ وَيَقُولُ‏:‏ ‏(‏وَإِنْ يَسْتَغِيثُوا يُغَاثُوا بِمَاءٍ كَالْمُهْلِ يَشْوِي الْوُجُوهَ بِئْسَ الشَّرَابُ ‏)‏ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَهَكَذَا قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ عَنْ عُبَيْدِ اللَّهِ بْنِ بُسْرٍ وَلاَ نَعْرِفُ عُبَيْدَ اللَّهِ بْنَ بُسْرٍ إِلاَّ فِي هَذَا الْحَدِيثِ وَقَدْ رَوَى صَفْوَانُ بْنُ عَمْرٍو عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ صَاحِبِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ هَذَا الْحَدِيثِ وَعَبْدُ اللَّهِ بْنُ بُسْرٍ لَهُ أَخٌ قَدْ سَمِعَ مِنَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَأُخْتُهُ قَدْ سَمِعَتْ مِنَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَعُبَيْدُ اللَّهِ بْنُ بُسْرٍ الَّذِي رَوَى عَنْهُ صَفْوَانُ بْنُ عَمْرٍو حَدِيثَ أَبِي أُمَامَةَ لَعَلَّهُ أَنْ يَكُونَ أَخَا عَبْدِ اللَّهِ بْنِ بُسْرٍ ‏.‏\hadithno{2583}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Umamah narrated regarding His (Allah's) statement:"He will be given water of Sadid to drink, he will swallow it..." that the Prophet (s.a.w) said: " It will be brought toward his mouth and he will dislike it, so whenever it is brought closer to him it will melt his face and the skin of his head will fall into it. Then whenever he drinks from it, his bowels will be severed until it comes out from his anus. Allah, the Blessed and Exalted says: "And they will be given water of Hamim to drink such that it cuts up their bowels..." and He says: "And if they call for drink they will be given water of Muhl which melts the faces, the worst of drinks}}
\hadithdefcmd{tirmidhi}{2584}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا رِشْدِينُ بْنُ سَعْدٍ، حَدَّثَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ دَرَّاجٍ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ‏:‏ ‏(‏كَالْمُهْلِ ‏)‏ كَعَكَرِ الزَّيْتِ فَإِذَا قُرِّبَ إِلَيْهِ سَقَطَتْ فَرْوَةُ وَجْهِهِ فِيهِ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لِسُرَادِقِ النَّارِ أَرْبَعَةُ جُدُرٍ كِثَفُ كُلِّ جِدَارٍ مِثْلُ مَسِيرَةِ أَرْبَعِينَ سَنَةً ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لَوْ أَنَّ دَلْوًا مِنْ غَسَّاقٍ يُهَرَاقُ فِي الدُّنْيَا لأَنْتَنَ أَهْلُ الدُّنْيَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ رِشْدِينَ بْنِ سَعْدٍ وَفِي رِشْدِينَ مَقَالٌ وَقَدْ تُكُلِّمَ فِيهِ مِنْ قِبَلِ حِفْظِهِ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ كِثَفُ كُلِّ جِدَارٍ ‏"‏ يَعْنِي غِلَظَهُ ‏.‏\hadithno{2584}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Abu Sa'eed Al-Khudri narrated that about:Kal Muhl, the Prophet (s.a.w) said: "Like boiling oil, such that whenever it is brought near him the skin of his face falls into it." And also with this chain, from the is Prophet SAW, that he said: "If a bucket of Ghassaq were poured out in the world, the people of the world would rot. (Da'if) And the meaning of his statement: "The Kithaf of each wall" is its thickness}}
\hadithdefcmd{tirmidhi}{2585}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ هَذِهِ الآيَةَ‏:‏ ‏(‏اتَّقُوا اللَّهَ حَقَّ تُقَاتِهِ وَلاَ تَمُوتُنَّ إِلاَّ وَأَنْتُمْ مُسْلِمُونَ ‏)‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ أَنَّ قَطْرَةً مِنَ الزَّقُّومِ قُطِرَتْ فِي دَارِ الدُّنْيَا لأَفْسَدَتْ عَلَى أَهْلِ الدُّنْيَا مَعَايِشَهُمْ فَكَيْفَ بِمَنْ يَكُونُ طَعَامَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2585}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah (s.a.w) recited this Ayah:Have the Taqwa of Allah as His due, and do not die except as Muslims. And the Messenger of Allah (s.a.w) said: "If only a drop of Az-Zaqqum were to drip into the abode of the world, it would spoil the peoples' livelihood, so how about the person for whom it is his food?}}
\hadithdefcmd{tirmidhi}{2586}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا عَاصِمُ بْنُ يُوسُفَ، حَدَّثَنَا قُطْبَةُ بْنُ عَبْدِ الْعَزِيزِ، عَنِ الأَعْمَشِ، عَنْ شِمْرِ بْنِ عَطِيَّةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُلْقَى عَلَى أَهْلِ النَّارِ الْجُوعُ فَيَعْدِلُ مَا هُمْ فِيهِ مِنَ الْعَذَابِ فَيَسْتَغِيثُونَ فَيُغَاثُونَ بِطَعَامٍ مِنْ ضَرِيعٍ لاَ يُسْمِنُ وَلاَ يُغْنِي مِنْ جُوعٍ فَيَسْتَغِيثُونَ بِالطَّعَامِ فَيُغَاثُونَ بِطَعَامٍ ذِي غُصَّةٍ فَيَذْكُرُونَ أَنَّهُمْ كَانُوا يُجِيزُونَ الْغُصَصَ فِي الدُّنْيَا بِالشَّرَابِ فَيَسْتَغِيثُونَ بِالشَّرَابِ فَيُرْفَعُ إِلَيْهِمُ الْحَمِيمُ بِكَلاَلِيبِ الْحَدِيدِ فَإِذَا دَنَتْ مِنْ وُجُوهِهِمْ شَوَتْ وُجُوهَهُمْ فَإِذَا دَخَلَتْ بُطُونَهُمْ قَطَّعَتْ مَا فِي بُطُونِهِمْ فَيَقُولُونَ ادْعُوا خَزَنَةَ جَهَنَّمَ فَيَقُولُونَ أَلَمْ تَكُ تَأْتِيكُمْ رُسُلُكُمْ بِالْبَيِّنَاتِ قَالُوا بَلَى ‏.‏ قَالُوا فَادْعُوا وَمَا دُعَاءُ الْكَافِرِينَ إِلاَّ فِي ضَلاَلٍ ‏.‏ قَالَ فَيَقُولُونَ ادْعُوا مَالِكًا فَيَقُولُونَ‏:‏ ‏(‏يَا مَالِكُ لِيَقْضِ عَلَيْنَا رَبُّكَ ‏)‏ قَالَ فَيُجِيبُهُمْ‏:‏ ‏(‏إِنَّكُمْ مَاكِثُونَ ‏)‏ ‏"‏ ‏.‏ قَالَ الأَعْمَشُ نُبِّئْتُ أَنَّ بَيْنَ دُعَائِهِمْ وَبَيْنَ إِجَابَةِ مَالِكٍ إِيَّاهُمْ أَلْفَ عَامٍ ‏.‏ قَالَ ‏"‏ فَيَقُولُونَ ادْعُوا رَبَّكُمْ فَلاَ أَحَدَ خَيْرٌ مِنْ رَبِّكُمْ فَيَقُولُونَ‏:‏ ‏(‏رَبَّنَا غَلَبَتْ عَلَيْنَا شِقْوَتُنَا وَكُنَّا قَوْمًا ضَالِّينَ * رَبَّنَا أَخْرِجْنَا مِنْهَا فَإِنْ عُدْنَا فَإِنَّا ظَالِمُونَ ‏)‏ قَالَ فَيُجِيبُهُمْ‏:‏ ‏(‏اخْسَؤُوا فِيهَا وَلاَ تُكَلِّمُونِ ‏)‏ قَالَ فَعِنْدَ ذَلِكَ يَئِسُوا مِنْ كُلِّ خَيْرٍ وَعِنْدَ ذَلِكَ يَأْخُذُونَ فِي الزَّفِيرِ وَالْحَسْرَةِ وَالْوَيْلِ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ وَالنَّاسُ لاَ يَرْفَعُونَ هَذَا الْحَدِيثَ ‏.‏ قَالَ أَبُو عِيسَى إِنَّمَا نَعْرِفُ هَذَا الْحَدِيثَ عَنِ الأَعْمَشِ عَنْ شِمْرِ بْنِ عَطِيَّةَ عَنْ شَهْرِ بْنِ حَوْشَبٍ عَنْ أُمِّ الدَّرْدَاءِ عَنْ أَبِي الدَّرْدَاءِ قَوْلَهُ وَلَيْسَ بِمَرْفُوعٍ ‏.‏ وَقُطْبَةُ بْنُ عَبْدِ الْعَزِيزِ هُوَ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏\hadithno{2586}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Ad-Darda' narrated that the Messenger of Allah (s.a.w) said:"The inhabitants of the Fire will suffer from a hunger equal to the punishment they experience, so they will seek relief, and be given to eat of Dari; which will neither nourish nor avail against hunger. So they will (again) seek food to relieve (their hunger), and they will be given to eat of a food that causes one to choke. Then they will remember that they used remedy for choking in the world by drinking something. So they will seek relief from drink. Then they will be given Hamim with meat hooks, so when it comes toward their faces it melts their faces, and when it enters their insides it cuts up what is inside of them. So (some of them) say: 'Call the keepers of Hell' so they say: Did there not come to you your Messengers with clear signs? They say: 'Yes!' They say: 'Then call as you like.' And the invocation of the disbelievers is nothing but in vain." He said: "They will say: 'Call Malik.' So they say: O Malik! Let your Lord make an end of us!'" He said: "So he answers them: Verily you shall abide forever. Al-A'mash said: "I was informed that there is a thousand years between their calling him, and Malik's answering them." He said: "They say: 'Call your Lord, for there is none better than your Lord.' So they will say: Our Lord! Our wretchedness over came us, and we were (an) erring people. Our Lord! Bring us out of this. If we ever return (to evil), indeed we shall be wrong doers."He said: "So the reply to them is: You remain in it in ignominy! And do not speak to Me." He said: "So with that, they loose hope of any good, and with that they are taken to moaning, despair and severe ruin}}
\hadithdefcmd{tirmidhi}{2587}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ سَعِيدِ بْنِ يَزِيدَ أَبِي شُجَاعٍ، عَنْ أَبِي السَّمْحِ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ‏:‏ ‏(‏وَهُمْ فِيهَا كَالِحُونَ‏)‏ قَالَ ‏"‏ تَشْوِيهِ النَّارُ فَتَقَلَّصُ شَفَتُهُ الْعُلْيَا حَتَّى تَبْلُغَ وَسَطَ رَأْسِهِ وَتَسْتَرْخِي شَفَتُهُ السُّفْلَى حَتَّى تَضْرِبَ سُرَّتَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَأَبُو الْهَيْثَمِ اسْمُهُ سُلَيْمَانُ بْنُ عَمْرِو بْنِ عَبْدٍ الْعُتْوَارِيُّ وَكَانَ يَتِيمًا فِي حِجْرِ أَبِي سَعِيدٍ ‏.‏\hadithno{2587}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Prophet (s.a.w) said:"And therein they will grimace in displace lips. -He will be grilled by the Fire until his upper lip is folded up reaching the middle of his head, And his bottom lip pains down, until it hits his navel}}
\hadithdefcmd{tirmidhi}{2588}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا سَعِيدُ بْنُ يَزِيدَ، عَنْ أَبِي السَّمْحِ، عَنْ عِيسَى بْنِ هِلاَلٍ الصَّدَفِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِي، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّ رُصَاصَةً مِثْلَ هَذِهِ وَأَشَارَ إِلَى مِثْلِ الْجُمْجُمَةِ أُرْسِلَتْ مِنَ السَّمَاءِ إِلَى الأَرْضِ وَهِيَ مَسِيرَةُ خَمْسِمِائَةِ سَنَةٍ لَبَلَغَتِ الأَرْضَ قَبْلَ اللَّيْلِ وَلَوْ أَنَّهَا أُرْسِلَتْ مِنْ رَأْسِ السِّلْسِلَةِ لَصَارَتْ أَرْبَعِينَ خَرِيفًا اللَّيْلَ وَالنَّهَارَ قَبْلَ أَنْ تَبْلُغَ أَصْلَهَا أَوْ قَعْرَهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِسْنَادُهُ حَسَنٌ صَحِيحٌ ‏.‏ وَسَعِيدُ بْنُ يَزِيدَ هُوَ مِصْرِيٌّ وَقَدْ رَوَى عَنْهُ اللَّيْثُ بْنُ سَعْدٍ وَغَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ ‏.‏\hadithno{2588}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin 'Amr bin Al-'As narrated that the Messenger of Allah said:"If a pellet like this one, and he pointed to one like Al-jumjumah were to be dropped from the heavens to the earth – and it is the distance of traveling five hundred years it would reach the earth before the night-fall. But if it were dropped from the top of the chain it would travel for forty years, day and night, before it would reach its foundation or bottom.” (Hasan)}}
\hadithdefcmd{tirmidhi}{2589}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ نَارُكُمْ هَذِهِ الَّتِي يُوقِدُ بَنُو آدَمَ جُزْءٌ وَاحِدٌ مِنْ سَبْعِينَ جُزءًا مِنْ حَرِّ جَهَنَّمَ ‏"‏ ‏.‏ قَالُوا وَاللَّهِ إِنْ كَانَتْ لَكَافِيَةً يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَإِنَّهَا فُضِّلَتْ بِتِسْعَةٍ وَسِتِّينَ جُزْءًا كُلُّهُنَّ مِثْلُ حَرِّهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَمَّامُ بْنُ مُنَبِّهٍ هُوَ أَخُو وَهْبِ بْنِ مُنَبِّهٍ وَقَدْ رَوَى عَنْهُ وَهْبٌ ‏.‏\hadithno{2589}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Prophet (s.a.w) said:"This Fire of yours, which the sons of Adam kindle, is one part from seventy parts of the heat of the Hell." They said: "By Allah! Would it not have been enough O Messenger of Allah?!" He said: "It is sixty-nine parts more – all of them similar in heat.” (Sahih)}}
\hadithdefcmd{tirmidhi}{2590}{حَدَّثَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنْ فِرَاسٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نَارُكُمْ هَذِهِ جُزْءٌ مِنْ سَبْعِينَ جُزْءًا مِنْ نَارِ جَهَنَّمَ لِكُلِّ جُزْءٍ مِنْهَا حَرُّهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي سَعِيدٍ ‏.‏\hadithno{2590}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed narrated that the Prophet (s.a.w) said:"This fire of yours is one part from seventy parts of the fire of Hell, each part of it is like the heat of this one}}
\hadithdefcmd{tirmidhi}{2591}{حَدَّثَنَا عَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ الْبَغْدَادِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا شَرِيكٌ، عَنْ عَاصِمٍ، هُوَ ابْنُ بَهْدَلَةَ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أُوقِدَ عَلَى النَّارِ أَلْفَ سَنَةٍ حَتَّى احْمَرَّتْ ثُمَّ أُوقِدَ عَلَيْهَا أَلْفَ سَنَةٍ حَتَّى ابْيَضَّتْ ثُمَّ أُوقِدَ عَلَيْهَا أَلْفَ سَنَةٍ حَتَّى اسْوَدَّتْ فَهِيَ سَوْدَاءُ مُظْلِمَةٌ ‏"‏ ‏.‏ حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ شَرِيكٍ، عَنْ عَاصِمٍ، عَنْ أَبِي صَالِحٍ، أَوْ رَجُلٍ آخَرَ عَنْ أَبِي هُرَيْرَةَ، نَحْوَهُ وَلَمْ يَرْفَعْهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ فِي هَذَا مَوْقُوفٌ أَصَحُّ وَلاَ أَعْلَمُ أَحَدًا رَفَعَهُ غَيْرَ يَحْيَى بْنِ أَبِي بُكَيْرٍ عَنْ شَرِيكٍ ‏.‏\hadithno{2591}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Prophet (s.a.w) said:"The Fire was kindled for one thousand years until it reddened, then it was kindled for one thousand years until it whitened, then it was kindled for one thousand years until it became blackened, so it is dark black}}
\hadithdefcmd{tirmidhi}{2592}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ الْوَلِيدِ الْكِنْدِيُّ الْكُوفِيُّ، حَدَّثَنَا الْمُفَضَّلُ بْنُ صَالِحٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اشْتَكَتِ النَّارُ إِلَى رَبِّهَا وَقَالَتْ أَكَلَ بَعْضِي بَعْضًا فَجَعَلَ لَهَا نَفَسَيْنِ نَفَسًا فِي الشِّتَاءِ وَنَفَسًا فِي الصَّيْفِ فَأَمَّا نَفَسُهَا فِي الشِّتَاءِ فَزَمْهَرِيرٌ وَأَمَّا نَفَسُهَا فِي الصَّيْفِ فَسَمُومٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ قَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ وَجْهٍ ‏.‏ وَالْمُفَضَّلُ بْنُ صَالِحٍ لَيْسَ عِنْدَ أَهْلِ الْحَدِيثِ بِذَلِكَ الْحَافِظِ ‏.‏\hadithno{2592}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated:that the Messenger of Allah (s.a.w) said: "The Fire complained to its Lord. It said: 'Some parts of me consume other parts.' So He allowed it to take two breaths: one during the winter, and during the summer. As for the breath in the winter then it is Zamharir, and as for the breath in the summer then it is Samum. Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2593}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، وَهِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ - قَالَ هِشَامٌ ‏"‏ يَخْرُجُ مِنَ النَّارِ ‏"‏ ‏.‏ وَقَالَ شُعْبَةُ ‏"‏ أَخْرِجُوا مِنَ النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَكَانَ فِي قَلْبِهِ مِنَ الْخَيْرِ مَا يَزِنُ شَعِيرَةً أَخْرِجُوا مِنَ النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَكَانَ فِي قَلْبِهِ مِنَ الْخَيْرِ مَا يَزِنُ بُرَّةً أَخْرِجُوا مِنَ النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَكَانَ فِي قَلْبِهِ مِنَ الْخَيْرِ مَا يَزِنُ ذَرَّةً ‏"‏ ‏.‏ وَقَالَ شُعْبَةُ ‏"‏ مَا يَزِنُ ذُرَةً ‏"‏ ‏.‏ مُخَفَّفَةً ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2593}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{From Anas, that the Messenger of Allah (s.a.w) said – Hisham (one of the narrators) narrated it:“Some will exit the Fire,” Shu`bah (another narrator) narrated it: 'Remove from the Fire whoever said La ilaha illallah and had good in his heart equal to the weight of a grain of barley. Remove from the Fire anyone who said La Ilaha illallah and had good in his heart equal to the weight of a grain of wheat. Remove from the Fire anyone who said La ilaha illallah and had good in his heart equal to the weight of a speck.” And Shubah said: “What is equal to the weight of a light piece of corn.” (Sahih) Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2594}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ مُبَارَكِ بْنِ فَضَالَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ أَنَسٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَقُولُ اللَّهُ أَخْرِجُوا مِنَ النَّارِ مَنْ ذَكَرَنِي يَوْمًا أَوْ خَافَنِي فِي مَقَامٍ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2594}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Anas said that the Prophet (s.a.w) said:"Allah will say: 'Remove from the Fire whoever remembered Me one day, or feared Me while in a state of sinning}}
\hadithdefcmd{tirmidhi}{2595}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ السَّلْمَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَعْرِفُ آخِرَ أَهْلِ النَّارِ خُرُوجًا رَجُلٌ يَخْرُجُ مِنْهَا زَحْفًا فَيَقُولُ يَا رَبِّ قَدْ أَخَذَ النَّاسُ الْمَنَازِلَ ‏.‏ قَالَ فَيُقَالُ لَهُ انْطَلِقْ فَادْخُلِ الْجَنَّةَ ‏.‏ قَالَ فَيَذْهَبُ لِيَدْخُلَ فَيَجِدُ النَّاسَ قَدْ أَخَذُوا الْمَنَازِلَ فَيَرْجِعُ فَيَقُولُ يَا رَبِّ قَدْ أَخَذَ النَّاسُ الْمَنَازِلَ ‏.‏ قَالَ فَيُقَالُ لَهُ أَتَذْكُرُ الزَّمَانَ الَّذِي كُنْتَ فِيهِ فَيَقُولُ نَعَمْ ‏.‏ فَيُقَالُ لَهُ تَمَنَّ ‏.‏ قَالَ فَيَتَمَنَّى فَيُقَالُ لَهُ فَإِنَّ لَكَ مَا تَمَنَّيْتَ وَعَشَرَةَ أَضْعَافِ الدُّنْيَا ‏.‏ قَالَ فَيَقُولُ أَتَسْخَرُ بِي وَأَنْتَ الْمَلِكُ ‏"‏ ‏.‏ قَالَ فَلَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ضَحِكَ حَتَّى بَدَتْ نَوَاجِذُهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2595}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Masud narrated that the Messenger of Allah (s.a.w) said:"I know the last of the people of the Fire to depart from it. A man will exit it crawling, and he will say: 'O Lord! The people have taken all the places.'" He said: "So it will be said to him: 'Go to Paradise to enter Paradise.' So he will go to enter, but he will see that the people have taken all the places. He will return and say: 'O Lord! The people have taken all of the places.' So it will be said to him: 'Do you remember the times you used to live in?' And he will say: 'Yes.' So it will be said to him: 'Wish, He will wish for something, and it will be said to him: 'For you is whatever you wished for, and ten times the world.' He will say: 'Do you mock me while you are the King?'" He (Ibn Masud) said: "I saw the Messenger of Allah (s.a.w) laugh until his molars were visible}}
\hadithdefcmd{tirmidhi}{2596}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَعْرِفُ آخِرَ أَهْلِ النَّارِ خُرُوجًا مِنَ النَّارِ وَآخِرَ أَهْلِ الْجَنَّةِ دُخُولاً الْجَنَّةَ يُؤْتَى بِرَجُلٍ فَيَقُولُ سَلُوا عَنْ صِغَارِ ذُنُوبِهِ وَاخْبَئُوا كِبَارَهَا ‏.‏ فَيُقَالُ لَهُ عَمِلْتَ كَذَا وَكَذَا يَوْمَ كَذَا وَكَذَا عَمِلْتَ كَذَا وَكَذَا فِي يَوْمِ كَذَا وَكَذَا ‏.‏ قَالَ فَيُقَالُ لَهُ فَإِنَّ لَكَ مَكَانَ كُلِّ سَيِّئَةٍ حَسَنَةً ‏.‏ قَالَ فَيَقُولُ يَا رَبِّ لَقَدْ عَمِلْتُ أَشْيَاءَ مَا أَرَاهَا هَا هُنَا ‏"‏ ‏.‏ قَالَ فَلَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَضْحَكُ حَتَّى بَدَتْ نَوَاجِذُهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2596}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Dharr narrated that the Messenger of Allah (s.a.w) said:" I know the last of the people of the Fire to depart from the Fire and the last of the people of Paradise to enter Paradise. A man will be brought forth and He (s.a.w) will say: 'Ask about his small sins and hide his large sins.' So it will be said to him: 'Did you do this and that on such and such a day, did you do this and that on such- and – such a day?'” He said: “Then it will be said to him; 'For each of your sins you shall have a reward.'” He (s.a.w) said: “So he will say: 'O Lord! I have done things that I do not see here.'” He (Abu Dharr) said: “I saw the Messenger of Allah (s.a.w) laugh until his molars were visible.” (Sahih)}}
\hadithdefcmd{tirmidhi}{2597}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُعَذَّبُ نَاسٌ مِنْ أَهْلِ التَّوْحِيدِ فِي النَّارِ حَتَّى يَكُونُوا فِيهَا حُمَمًا ثُمَّ تُدْرِكُهُمُ الرَّحْمَةُ فَيُخْرَجُونَ وَيُطْرَحُونَ عَلَى أَبْوَابِ الْجَنَّةِ ‏.‏ قَالَ فَيَرُشُّ عَلَيْهِمْ أَهْلُ الْجَنَّةِ الْمَاءَ فَيَنْبُتُونَ كَمَا يَنْبُتُ الْغُثَاءُ فِي حِمَالَةِ السَّيْلِ ثُمَّ يَدْخُلُونَ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرٍ ‏.‏\hadithno{2597}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir narrated that the Messenger of Allah (s.a.w) said:" Some of the people of Tawhid will be punished in the Fire until they are coals. Then the Mercy (of Allah) will reach them, they will be taken out and tossed at the doors of Paradise." He said: " The people of Paradise will pour water over them, and they will sprout as the debris carried by the flood sprouts, then they will enter Paradise}}
\hadithdefcmd{tirmidhi}{2598}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ يُخْرَجُ مِنَ النَّارِ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ ذَرَّةٍ مِنَ الإِيمَانِ ‏"‏ ‏.‏ قَالَ أَبُو سَعِيدٍ فَمَنْ شَكَّ فَلْيَقْرَأْ‏:‏ ‏(‏إِنَّ اللَّهَ لاَ يَظْلِمُ مِثْقَالَ ذَرَّةٍ ‏)‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2598}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Sa'eed Al-Khudri narrated that the Messenger of Allah (s.a.w) said:"Whoever had the weight of a speck of faith in his heart will depart from the Fire." Abu Sa'eed said: "Whoever has doubt then let him recite: Indeed Allah does not deal unjustly with even the weight of a speck}}
\hadithdefcmd{tirmidhi}{2599}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا رِشْدِينُ بْنُ سَعْدٍ، حَدَّثَنِي ابْنُ أَنْعُمَ، عَنْ أَبِي عُثْمَانَ، أَنَّهُ حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ رَجُلَيْنِ مِمَّنْ دَخَلَ النَّارَ اشْتَدَّ صِيَاحُهُمَا فَقَالَ الرَّبُّ عَزَّ وَجَلَّ أَخْرِجُوهُمَا ‏.‏ فَلَمَّا أُخْرِجَا قَالَ لَهُمَا لأَىِّ شَيْءٍ اشْتَدَّ صِيَاحُكُمَا قَالاَ فَعَلْنَا ذَلِكَ لِتَرْحَمَنَا ‏.‏ قَالَ إِنَّ رَحْمَتِي لَكُمَا أَنْ تَنْطَلِقَا فَتُلْقِيَا أَنْفُسَكُمَا حَيْثُ كُنْتُمَا مِنَ النَّارِ ‏.‏ فَيَنْطَلِقَانِ فَيُلْقِي أَحَدُهُمَا نَفْسَهُ فَيَجْعَلُهَا عَلَيْهِ بَرْدًا وَسَلاَمًا وَيَقُومُ الآخَرُ فَلاَ يُلْقِي نَفْسَهُ فَيَقُولُ لَهُ الرَّبُّ عَزَّ وَجَلَّ مَا مَنَعَكَ أَنْ تُلْقِيَ نَفْسَكَ كَمَا أَلْقَى صَاحِبُكَ فَيَقُولُ يَا رَبِّ إِنِّي لأَرْجُو أَنْ لاَ تُعِيدَنِي فِيهَا بَعْدَ مَا أَخْرَجْتَنِي ‏.‏ فَيَقُولُ لَهُ الرَّبُّ لَكَ رَجَاؤُكَ ‏.‏ فَيَدْخُلاَنِ جَمِيعًا الْجَنَّةَ بِرَحْمَةِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى إِسْنَادُ هَذَا الْحَدِيثِ ضَعِيفٌ لأَنَّهُ عَنْ رِشْدِينَ بْنِ سَعْدٍ ‏.‏ وَرِشْدِينُ بْنُ سَعْدٍ هُوَ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ عَنِ ابْنِ أَنْعُمَ وَهُوَ الإِفْرِيقِيُّ وَالإِفْرِيقِيُّ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏\hadithno{2599}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Indeed two men among those who entered the Fire will be screaming violently. So the Lord, Blessed and Exalted, will say: 'Take them out.' Then when they are taken out He will say: 'What caused you to scream so violently?' They will say: 'We did that so You would have mercy on us.' He will say: 'My mercy for you is that you both go and throw yourselves where you were in the Fire.' So they will go. One of them will throw himself in, and He will make it cool and peaceful for him. And the other will stand there and not throw himself in, so the Lord, Mighty and Majestic, will say to him: 'What prevented you from throwing yourself in as your companion did?' He will say: 'O Lord! I hope that you will not return me to it aftrr You have taken me out.' So the Lord, Blessed and Exalted, will say to him: 'For you is what you hoped for,' and so they will both enter Paradise together by the mercy of Allah}}
\hadithdefcmd{tirmidhi}{2600}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا الْحَسَنُ بْنُ ذَكْوَانَ، عَنْ أَبِي رَجَاءٍ الْعُطَارِدِيِّ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيَخْرُجَنَّ قَوْمٌ مِنْ أُمَّتِي مِنَ النَّارِ بِشَفَاعَتِي يُسَمَّوْنَ الْجَهَنَّمِيُّونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو رَجَاءٍ الْعُطَارِدِيُّ اسْمُهُ عِمْرَانُ بْنُ تَيْمٍ وَيُقَالُ ابْنُ مِلْحَانَ ‏.‏\hadithno{2600}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Imran bin Husain narrated that the Prophet (s.a.w) said:'A group from my Ummah will depart from the Fire through my intercession, and they will be called the Jahannamiyyun}}
\hadithdefcmd{tirmidhi}{2601}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا رَأَيْتُ مِثْلَ النَّارِ نَامَ هَارِبُهَا وَلاَ مِثْلَ الْجَنَّةِ نَامَ طَالِبُهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ يَحْيَى بْنِ عُبَيْدِ اللَّهِ ‏.‏ وَيَحْيَى بْنُ عُبَيْدِ اللَّهِ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ تَكَلَّمَ فِيهِ شُعْبَةُ وَيَحْيَى بْنُ عُبَيْدِ اللَّهِ هُوَ ابْنُ مَوْهَبٍ وَهُوَ مَدَنِيٌّ ‏.‏\hadithno{2601}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"I have not seen the likes of the Fire in which the one who runs from it sleeps, nor the likes of Paradise in which the one who seeks it sleeps}}
\hadithdefcmd{tirmidhi}{2602}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي رَجَاءٍ الْعُطَارِدِيِّ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اطَّلَعْتُ فِي الْجَنَّةِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا الْفُقَرَاءَ وَاطَّلَعْتُ فِي النَّارِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ ‏"‏ ‏.‏\hadithno{2602}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn 'Abbas narrated that the Messenger Of Allah (s.a.w) said:"I looked into Paradise and I saw that the most of its people were the poor; and I looked into the Fire and I saw that most of its people were women}}
\hadithdefcmd{tirmidhi}{2603}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الْوَهَّابِ الثَّقَفِيُّ، قَالُوا حَدَّثَنَا عَوْفٌ، هُوَ ابْنُ أَبِي جَمِيلَةَ عَنْ أَبِي رَجَاءٍ الْعُطَارِدِيِّ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اطَّلَعْتُ فِي النَّارِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ وَاطَّلَعْتُ فِي الْجَنَّةِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا الْفُقَرَاءَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا يَقُولُ عَوْفٌ عَنْ أَبِي رَجَاءٍ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ وَيَقُولُ أَيُّوبُ عَنْ أَبِي رَجَاءٍ عَنِ ابْنِ عَبَّاسٍ وَكِلاَ الإِسْنَادَيْنِ لَيْسَ فِيهِمَا مَقَالٌ وَيُحْتَمَلُ أَنْ يَكُونَ أَبُو رَجَاءٍ سَمِعَ مِنْهُمَا جَمِيعًا وَقَدْ رَوَى غَيْرُ عَوْفٍ أَيْضًا هَذَا الْحَدِيثَ عَنْ أَبِي رَجَاءٍ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ‏.‏\hadithno{2603}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Imran bin Husain narrated that the Messenger Of Allah (s.a.w) said:" I looked into the Fire and I saw that most of its people are women, and I looked into Paradise and I saw that most of its people were the poor." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2604}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَهْوَنَ أَهْلِ النَّارِ عَذَابًا يَوْمَ الْقِيَامَةِ رَجُلٌ فِي إِخْمَصِ قَدَمَيْهِ جَمْرَتَانِ يَغْلِي مِنْهُمَا دِمَاغُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ وَأَبِي سَعِيدٍ الْخُدْرِيِّ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{2604}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{An-Numan bin Bashir narrated that the Messenger Of Allah (s.a.w) said:"Indeed the person among the inhabitants of the Fire punished least [on the Day of Judgment] is a man who has two coals beneath his feet, which cause his brain to boil." Other chains report similar narrations}}
\hadithdefcmd{tirmidhi}{2605}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، قَالَ سَمِعْتُ حَارِثَةَ بْنَ وَهْبٍ الْخُزَاعِيَّ، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَلاَ أُخْبِرُكُمْ بِأَهْلِ الْجَنَّةِ كُلُّ ضَعِيفٍ مُتَضَعِّفٍ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ أَلاَ أُخْبِرُكُمْ بِأَهْلِ النَّارِ كُلُّ عُتُلٍّ جَوَّاظٍ مُتَكَبِّرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2605}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Harithah bin Wahb Al-Khuzai narrated that the Messenger of Allah (s.a.w) said:"Should I not inform you about the people of Paradise: They are every humble and weak person, who if he were to make an Oath by Allah, He would fulfill it. Should I not inform you about the people of the Fire: They are every prideful, swaggering, ill-speaking person}}
\hadithdefcmd{tirmidhi}{2795}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ زُرْعَةَ بْنِ مُسْلِمِ بْنِ جَرْهَدٍ الأَسْلَمِيِّ، عَنْ جَدِّهِ، جَرْهَدٍ قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِجَرْهَدٍ فِي الْمَسْجِدِ وَقَدِ انْكَشَفَ فَخِذُهُ فَقَالَ ‏ "‏ إِنَّ الْفَخِذَ عَوْرَةٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ مَا أَرَى إِسْنَادَهُ بِمُتَّصِلٍ ‏.‏\hadithno{2795}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Zur'ah bin Muslim bin Jardah Al-Aslami:about his grandfather Jarhad, he said: "The Prophet (ﷺ) passed by Jarhad in the Masjid and his thigh was exposed, so he said: 'Indeed the thigh is 'Awrah}}
